@@ -2,14 +2,15 @@
 from __future__ import annotations
 
 import asyncio
+import sys
+from collections.abc import Awaitable, Callable
 from datetime import datetime
 from json.decoder import JSONDecodeError
-import sys
-from typing import Any, Callable, cast
+from typing import Any, cast
 
+import backoff
 from aiohttp import ClientSession
 from aiohttp.client_exceptions import ClientResponseError
-import backoff
 
 from simplipy.const import DEFAULT_USER_AGENT, LOGGER
 from simplipy.errors import (
@@ -27,12 +28,14 @@ from simplipy.util.auth import (
     DEFAULT_CLIENT_ID,
     DEFAULT_REDIRECT_URI,
 )
+from simplipy.util.dt import utcnow
 from simplipy.websocket import WebsocketClient
 
 API_URL_HOSTNAME = "api.simplisafe.com"
 API_URL_BASE = f"https://{API_URL_HOSTNAME}/v1"
 
 DEFAULT_REQUEST_RETRIES = 4
+DEFAULT_MEDIA_RETRIES = 4
 DEFAULT_TIMEOUT = 10
 DEFAULT_TOKEN_EXPIRATION_WINDOW = 5
 
@@ -44,21 +47,31 @@ class API:  # pylint: disable=too-many-instance-attributes
     :meth:`simplipy.api.API.async_from_auth` and
     :meth:`simplipy.api.API.async_from_refresh_token` methods should be used.
 
-    :param session: The ``aiohttp`` ``ClientSession`` session used for all HTTP requests
-    :type session: ``aiohttp.client.ClientSession``
-    :param request_retries: The default number of request retries to use
-    :type request_retries: ``int``
+    Args:
+        session: session: An optional ``aiohttp`` ``ClientSession``.
+        request_retries: The default number of request retries to use.
+        media_retries: The default number of request retries to use to
+            fetch media files.
     """
 
     def __init__(
         self,
         *,
-        session: ClientSession,
         request_retries: int = DEFAULT_REQUEST_RETRIES,
+        media_retries: int = DEFAULT_MEDIA_RETRIES,
+        session: ClientSession,
     ) -> None:
-        """Initialize."""
-        self._refresh_token_callbacks: list[Callable[..., None]] = []
+        """Initialize.
+
+        Args:
+            session: An optional ``aiohttp`` ``ClientSession``.
+            request_retries: The default number of request retries to use.
+        """
+        self._refresh_token_callbacks: list[
+            Callable[[str], Awaitable[None] | None]
+        ] = []
         self._request_retries = request_retries
+        self._media_retries = media_retries
         self.session: ClientSession = session
 
         # These will get filled in after initial authentication:
@@ -70,7 +83,16 @@ class API:  # pylint: disable=too-many-instance-attributes
         self.user_id: int | None = None
         self.websocket: WebsocketClient | None = None
 
-        self.async_request = self._wrap_request_method(self._request_retries)
+        self.async_request = self._wrap_request_method(
+            request_retries=self._request_retries,
+            retry_codes=[401, 409],
+            request_func=self._async_api_request,
+        )
+        self._async_media_data = self._wrap_request_method(
+            request_retries=self._media_retries,
+            retry_codes=[401, 404, 409],
+            request_func=self._async_media_request,
+        )
 
     @classmethod
     async def async_from_auth(
@@ -78,20 +100,24 @@ class API:  # pylint: disable=too-many-instance-attributes
         authorization_code: str,
         code_verifier: str,
         *,
-        session: ClientSession,
         request_retries: int = DEFAULT_REQUEST_RETRIES,
+        session: ClientSession,
     ) -> API:
         """Get an authenticated API object from an Authorization Code and Code Verifier.
 
-        :param authorization_code: The Authorization Code
-        :type authorization_code: ``str``
-        :param code_verifier: The Code Verifier
-        :type code_verifier: ``str``
-        :param session: The ``aiohttp`` ``ClientSession`` session used for HTTP requests
-        :type session: ``aiohttp.client.ClientSession``
-        :param request_retries: The default number of request retries to use
-        :type request_retries: ``int``
-        :rtype: :meth:`simplipy.api.API`
+        Args:
+            authorization_code: The Authorization Code.
+            code_verifier: The Code Verifier.
+            request_retries: The default number of request retries to use.
+            session: An optional ``aiohttp`` ``ClientSession``.
+
+        Returns:
+            An authenticated API object.
+
+        Raises:
+            InvalidCredentialsError: Raised on invalid username/password.
+            RequestError: Raised on general HTTP error.
+            SimplipyError: Raised on an unknown error.
         """
         api = cls(session=session, request_retries=request_retries)
 
@@ -125,18 +151,18 @@ class API:  # pylint: disable=too-many-instance-attributes
         cls,
         refresh_token: str,
         *,
-        session: ClientSession,
         request_retries: int = DEFAULT_REQUEST_RETRIES,
+        session: ClientSession,
     ) -> API:
         """Get an authenticated API object from a refresh token.
 
-        :param refresh_token: The refresh token
-        :type refresh_token: ``str``
-        :param session: An ``aiohttp`` ``ClientSession``
-        :type session: ``aiohttp.client.ClientSession``
-        :param request_retries: The default number of request retries to use
-        :type request_retries: ``int``
-        :rtype: :meth:`simplipy.api.API`
+        Args:
+            refresh_token: A refresh token.
+            request_retries: The default number of request retries to use.
+            session: An optional ``aiohttp`` ``ClientSession``.
+
+        Returns:
+            An authenticated API object.
         """
         api = cls(session=session, request_retries=request_retries)
         api.refresh_token = refresh_token
@@ -153,12 +179,10 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         LOGGER.debug("Error during request attempt: %s", err)
 
-        if err.status == 401:
-            assert self._token_last_refreshed
-
+        if err.status == 401 and self._token_last_refreshed:
             # Calculate the window between now and the last time the token was
             # refreshed:
-            window = (datetime.utcnow() - self._token_last_refreshed).total_seconds()
+            window = (utcnow() - self._token_last_refreshed).total_seconds()
 
             # Since we might have multiple requests (each running their own retry
             # sequence) land here, we only refresh the access token if it hasn't
@@ -181,7 +205,17 @@ class API:  # pylint: disable=too-many-instance-attributes
     async def _async_api_request(
         self, method: str, endpoint: str, url_base: str = API_URL_BASE, **kwargs: Any
     ) -> dict[str, Any]:
-        """Execute an API request."""
+        """Make an API request.
+
+        Args:
+            method: An HTTP method.
+            endpoint: A relative API endpoint.
+            url_base: The base URL of the API.
+            **kwargs: Additional kwargs to send with the request.
+
+        Returns:
+            An API response payload.
+        """
         kwargs.setdefault("headers", {})
         kwargs["headers"].setdefault("Host", API_URL_HOSTNAME)
         kwargs["headers"]["Content-Type"] = "application/json; charset=utf-8"
@@ -217,70 +251,168 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         return data
 
+    async def async_media(self, url: str) -> bytes | None:
+        """Fetch a media file and return raw bytes to caller.
+
+        Args:
+            url: An absolute url for the media file.
+
+        Returns:
+            The raw bytes of the media file.
+        """
+        data = await self._async_media_data(url)
+        return cast(bytes, data["bytes"])
+
+    async def _async_media_request(self, url: str) -> dict[str, Any]:
+        """Fetch a media file.
+
+        Args:
+            url: An absolute url for the media file.
+
+        Returns:
+            A dict that looks like { "bytes": <raw-bytes> }.
+        """
+        async with self.session.request(
+            "get",
+            url,
+            headers={
+                "User-Agent": DEFAULT_USER_AGENT,
+                "Authorization": f"Bearer {self.access_token}",
+            },
+        ) as resp:
+            resp.raise_for_status()
+            return {"bytes": await resp.read()}
+
     @staticmethod
     def _handle_on_giveup(_: dict[str, Any]) -> None:
-        """Handle a give up after retries are exhausted."""
+        """Handle a give up after retries are exhausted.
+
+        Raises:
+            RequestError: Raised upon an underlying HTTP error.
+        """
         err_info = sys.exc_info()
         err = err_info[1].with_traceback(err_info[2])  # type: ignore
         raise RequestError(err) from err
 
     def _save_token_data_from_response(self, token_data: dict[str, Any]) -> None:
-        """Save token data from a token response."""
-        self._token_last_refreshed = datetime.utcnow()
+        """Save token data from a token response.
+
+        Args:
+            token_data: An API response payload.
+        """
+        self._token_last_refreshed = utcnow()
         self.access_token = token_data["access_token"]
-        self.refresh_token = token_data["refresh_token"]
+        if refresh_token := token_data.get("refresh_token"):
+            self.refresh_token = refresh_token
 
     @staticmethod
-    def is_fatal_error(err: ClientResponseError) -> bool:
+    def is_fatal_error(
+        retriable_error_codes: list[int],
+    ) -> Callable[[ClientResponseError], bool]:
         """Determine whether a ClientResponseError is fatal and shouldn't be retried.
 
-        In general, we retry anything outside of HTTP 4xx codes (client errors) with a
-        few exceptions:
+        When sending general API requests:
 
         1. 401: We catch this, refresh the access token, and retry the original request.
         2. 409: SimpliSafe base stations regular synchronize themselves with the API,
                 which is where this error can occur; we can't control when/how that
                 happens (e.g., we might query the API in the middle of a base station
                 update), so it should be viewed as retryable.
-        """
-        assert isinstance(err.status, int)
-        if err.status in (401, 409):
-            return False
-        return 400 <= err.status < 500
 
-    def _wrap_request_method(self, request_retries: int) -> Callable:
-        """Wrap the request method in backoff/retry logic."""
-        return cast(
-            Callable,
-            backoff.on_exception(
-                backoff.expo,
-                ClientResponseError,
-                giveup=self.is_fatal_error,
-                jitter=backoff.random_jitter,
-                logger=LOGGER,
-                max_tries=request_retries,
-                on_backoff=self._async_handle_on_backoff,
-                on_giveup=self._handle_on_giveup,
-            )(self._async_api_request),
-        )
+        But when fetching media files:
+
+        3. 404: When fetching media files, you may get a 404 if the media file is not
+                yet available to read. Keep trying however, and it will eventually
+                return a 200.
+
+        Args:
+            retriable_error_codes: A list of retriable error status codes.
+
+        Returns:
+            A callable function used by backoff to check for errors.
+        """
+
+        def check(err: ClientResponseError) -> bool:
+            """Perform the check.
+
+            Args:
+                err: An ``aiohttp`` ``ClientResponseError``
+
+            Returns:
+                Whether the error is a fatal one.
+            """
+            if err.status in retriable_error_codes:
+                return False
+            return 400 <= err.status < 500
+
+        return check
+
+    def _wrap_request_method(
+        self,
+        request_retries: int,
+        retry_codes: list[int],
+        request_func: Callable[..., Awaitable[dict[str, Any]]],
+    ) -> Callable[..., Awaitable[dict[str, Any]]]:
+        """Wrap a request method in backoff/retry logic.
+
+        Args:
+            request_retries: The number of retries to give a failed request.
+            retry_codes: A list of HTTP status codes that cause the retry
+                loop to continue.
+            request_func: A function that performs the request.
+
+        Returns:
+            A version of the request callable that can do retries.
+        """
+        return backoff.on_exception(
+            backoff.expo,
+            ClientResponseError,
+            giveup=self.is_fatal_error(retry_codes),  # type: ignore[arg-type]
+            jitter=backoff.random_jitter,
+            logger=LOGGER,
+            max_tries=request_retries,
+            on_backoff=self._async_handle_on_backoff,  # type: ignore[arg-type]
+            on_giveup=self._handle_on_giveup,  # type: ignore[arg-type]
+        )(request_func)
 
     def disable_request_retries(self) -> None:
         """Disable the request retry mechanism."""
-        self.async_request = self._wrap_request_method(1)
+        self.async_request = self._wrap_request_method(
+            request_retries=1,
+            retry_codes=[401, 409],
+            request_func=self._async_api_request,
+        )
+        self._async_media_data = self._wrap_request_method(
+            request_retries=1,
+            retry_codes=[401, 404, 409],
+            request_func=self._async_media_request,
+        )
 
     def enable_request_retries(self) -> None:
         """Enable the request retry mechanism."""
-        self.async_request = self._wrap_request_method(self._request_retries)
+        self.async_request = self._wrap_request_method(
+            request_retries=self._request_retries,
+            retry_codes=[401, 409],
+            request_func=self._async_api_request,
+        )
+        self._async_media_data = self._wrap_request_method(
+            request_retries=self._media_retries,
+            retry_codes=[401, 404, 409],
+            request_func=self._async_media_request,
+        )
 
     def add_refresh_token_callback(
-        self, callback: Callable[..., Any]
-    ) -> Callable[..., None]:
+        self, callback: Callable[[str], Awaitable[None] | None]
+    ) -> Callable[[], None]:
         """Add a callback that should be triggered when tokens are refreshed.
 
         Note that callbacks should expect to receive a refresh token as a parameter.
 
-        :param callback: The method to call after receiving an event.
-        :type callback: ``Callable[..., None]``
+        Args:
+            callback: The callback to execute.
+
+        Returns:
+            A callable to cancel the callback.
         """
         self._refresh_token_callbacks.append(callback)
 
@@ -296,14 +428,15 @@ class API:  # pylint: disable=too-many-instance-attributes
         In the dict that is returned, the keys are the subscription ID and the values
         are actual ``System`` objects.
 
-        :rtype: ``Dict[int, simplipy.system.System]``
+        Returns:
+            A dictionary of system IDs to System objects.
         """
         systems: dict[int, SystemV2 | SystemV3] = {}
 
         await self.async_update_subscription_data()
 
         for sid, subscription in self.subscription_data.items():
-            if not subscription["status"]["isActive"] != 0:
+            if not subscription["status"]["hasBaseStation"]:
                 LOGGER.info("Skipping inactive subscription: %s", sid)
                 continue
 
@@ -312,8 +445,7 @@ class API:  # pylint: disable=too-many-instance-attributes
                 continue
 
             system: SystemV2 | SystemV3
-            version = subscription["location"]["system"]["version"]
-            if version == 2:
+            if subscription["location"]["system"]["version"] == 2:
                 system = SystemV2(self, sid)
             else:
                 system = SystemV3(self, sid)
@@ -330,6 +462,11 @@ class API:  # pylint: disable=too-many-instance-attributes
         """Initiate a refresh of the access/refresh tokens.
 
         Note that this will execute any callbacks added via add_refresh_token_callback.
+
+        Raises:
+            InvalidCredentialsError: Raised on invalid username/password.
+            RequestError: Raised on general HTTP error.
+            SimplipyError: Raised on an unknown error.
         """
         try:
             token_data = await self._async_api_request(
