@@ -22,6 +22,12 @@ class InvalidCredentialsError(SimplipyError):
     pass
 
 
+class MaxUserPinsExceededError(SimplipyError):
+    """An error related to exceeding the maximum number of user PINs."""
+
+    pass
+
+
 class PinError(SimplipyError):
     """An error related to invalid PINs or PIN operations."""
 
@@ -34,18 +40,6 @@ class RequestError(SimplipyError):
     pass
 
 
-class Verify2FAError(SimplipyError):
-    """An error related to the 2FA process."""
-
-    pass
-
-
-class Verify2FAPending(SimplipyError):
-    """An "error" related to 2FA still pending."""
-
-    pass
-
-
 class WebsocketError(SimplipyError):
     """An error related to generic websocket errors."""
 
@@ -89,13 +83,19 @@ DATA_ERROR_MAP: dict[str, type[SimplipyError]] = {
 
 
 def raise_on_data_error(data: dict[str, Any] | None) -> None:
-    """Raise a specific error if the data payload suggests there is one."""
+    """Raise a specific error if the data payload suggests there is one.
+
+    Args:
+        data: An optional API response payload.
+
+    Raises:
+        error: A SimplipyError subclass.
+    """
     if not data:
         return
 
-    error_type = data.get("type")
-
-    if error_type not in DATA_ERROR_MAP:
+    if (error_type := data.get("type")) not in DATA_ERROR_MAP:
         return
 
-    raise DATA_ERROR_MAP[error_type](data["message"])
+    error = DATA_ERROR_MAP[error_type](data["message"])
+    raise error
